Module data

Module data 

Contains trait for for reading voxel data, and a simple implementation for it.

Structs

VoxModels
A VoxBuffer implementation that collects the models into a Vec and is generic over the kind of voxel data.

Traits

VoxBuffer
A trait for data structures that can constructed from a VOX file. [crate::vox::VoxData] implements this for convienience, but you can also implement this for your own voxel model types.
VoxModelBuffer
Trait for reading a single model.

Type Aliases

VoxData
A simple implementation of VoxBuffer that collects voxels into Vecs.