pub struct MaterialPalette { /* private fields */ }Expand description
A palette of materials
Work-in-Progress
This interface his likely to change in the future and is not fully implemented yet.
Implementations
Sourceimpl MaterialPalette
impl MaterialPalette
Sourcepub fn get(&self, material_id: ColorIndex) -> Option<&Material>
pub fn get(&self, material_id: ColorIndex) -> Option<&Material>
Returns the material with ID material_id from the palette. Returns
None, if there is no material with this ID. This is equivalent to
material_palette[material_id].
Sourcepub fn iter(&self) -> MaterialPaletteIter<'_> ⓘ
pub fn iter(&self) -> MaterialPaletteIter<'_> ⓘ
Creates an iterator over all materials.
for (id, material) in material_palette.iter() {
println!("{} -> {:#?}", id, material);
}Work-in-Progress
This interface his likely to change in the future and is not fully implemented yet.