Contains trait for for reading voxel data, and a simple implementation for it.
Structs
- VoxModels
- A
VoxBufferimplementation that collects the models into aVecand is generic over the kind of voxel data.
Traits
- VoxBuffer
- A trait for data structures that can constructed from a VOX file.
[crate::vox::VoxData]implements this for convienience, but you can also implement this for your own voxel model types. - VoxModel
Buffer - Trait for reading a single model.
Type Aliases
- VoxData
- A simple implementation of
VoxBufferthat collects voxels intoVecs.