pub struct Palette {
pub colors: [Color; 256],
}Expand description
A color palette. This contains colors indexec by u8. It is used to look up
colors of a voxel.
If you need MagicaVoxel’s default palette, you can either use
crate::default_palette::DEFAULT_PALETTE, or Palette::default.
Fields
colors: [Color; 256]The colors of the palette.
MagicaVoxel always set color 0 to be fully transparent. We don’t enfore
this, but this palette entry will never be written to a .VOX file.
Implementations
Sourceimpl Palette
impl Palette
Sourcepub fn is_default(&self) -> bool
pub fn is_default(&self) -> bool
Tests whether this is the crate::default_palette::DEFAULT_PALETTE.
Sourcepub fn get(&self, color_index: ColorIndex) -> Color
pub fn get(&self, color_index: ColorIndex) -> Color
Returns the color for an index. Since all color indices are valid, this
always returns a value. This is equivalent to palette[index].
Sourcepub fn iter(&self) -> PaletteIter<'_> ⓘ
pub fn iter(&self) -> PaletteIter<'_> ⓘ
Creates an iterator over all colors.
for (index, color) in palette.iter() {
println!("{} -> {:?}", index, color);
}Sourcepub fn read<R: Read>(reader: R) -> Result<Self, ReadError>
pub fn read<R: Read>(reader: R) -> Result<Self, ReadError>
Reads a color palette from a std::io::Read.
Sourcepub fn write<W: Write>(&self, writer: W) -> Result<(), WriteError>
pub fn write<W: Write>(&self, writer: W) -> Result<(), WriteError>
Writes the color palette to a std::io::Write.
MagicaVoxel fixes color 0 to be always fully transparent, and doesn’t include it in the file. Therefore this method will ignore the value for color 0.
Sourceimpl Palette
impl Palette
Sourcepub fn as_image(&self) -> RgbaImage
pub fn as_image(&self) -> RgbaImage
Converts the palette into an RGBA image. The image will have dimensions 256 (width) x 1 (height).
Sourcepub fn from_image(image: &RgbaImage) -> Palette
pub fn from_image(image: &RgbaImage) -> Palette
Converts a RGBA image to a color palette. Regardless of shape of the image, the first 256 pixels (row-first order) will be used. If there aren’t enough pixels, the rest of the palette will be transparent.
Note
VOX palettes have 256 colors, but VOX files only store the last 255 colors. The first color is always assumed to be fully transparent. Thus any color for the first palette entry will be lost once the palette is written to file.